"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchSynchronize = void 0;
var _dbDynamodb = require("@webiny/db-dynamodb");
var _apiDynamodbToElasticsearch = require("@webiny/api-dynamodb-to-elasticsearch");
var _entities = require("../entities");
class ElasticsearchSynchronize {
  constructor(params) {
    this.timer = params.timer;
    this.context = params.context;
  }
  async execute(params) {
    const {
      items,
      done,
      index
    } = params;
    if (items.length === 0) {
      return {
        done: true
      };
    }
    const table = (0, _entities.getTable)({
      type: "es",
      context: this.context
    });
    const readableItems = items.map(item => {
      const entity = this.getEntity(item);
      return entity.item.getBatch({
        PK: item.PK,
        SK: item.SK
      });
    });
    const tableItems = await (0, _dbDynamodb.batchReadAll)({
      items: readableItems,
      table
    });
    const elasticsearchSyncBuilder = (0, _apiDynamodbToElasticsearch.createSynchronizationBuilder)({
      timer: this.timer,
      context: this.context
    });
    /**
     * We need to find the items we have in the Elasticsearch but not in the DynamoDB-Elasticsearch table.
     */
    for (const item of items) {
      const exists = tableItems.some(ddbItem => {
        return ddbItem.PK === item.PK && ddbItem.SK === item.SK;
      });
      if (exists) {
        continue;
      }
      elasticsearchSyncBuilder.delete({
        index,
        id: item._id
      });
    }
    const executeWithRetry = elasticsearchSyncBuilder.build();
    await executeWithRetry();
    return {
      done
    };
  }
  getEntity(params) {
    const type = (0, _entities.getElasticsearchEntityType)(params);
    return (0, _entities.getElasticsearchEntity)({
      type,
      context: this.context
    });
  }
}
exports.ElasticsearchSynchronize = ElasticsearchSynchronize;

//# sourceMappingURL=ElasticsearchSynchronize.js.map