"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.listElasticsearchEntities = exports.getElasticsearchEntity = void 0;
var _getElasticsearchEntityType = require("./getElasticsearchEntityType");
const createPredicate = (app, tags) => {
  return item => {
    return item.app === app && tags.every(tag => item.tags.includes(tag));
  };
};
const getElasticsearchEntity = params => {
  const {
    type,
    context
  } = params;
  const getByPredicate = predicate => {
    return context.db.registry.getOneItem(predicate);
  };
  try {
    switch (type) {
      case _getElasticsearchEntityType.EntityType.CMS:
        return getByPredicate(createPredicate("cms", ["es"]));
      case _getElasticsearchEntityType.EntityType.PAGE_BUILDER:
        return getByPredicate(createPredicate("pb", ["es"]));
      case _getElasticsearchEntityType.EntityType.FORM_BUILDER:
        return getByPredicate(createPredicate("fb", ["es"]));
      case _getElasticsearchEntityType.EntityType.FORM_BUILDER_SUBMISSION:
        return getByPredicate(createPredicate("fb", ["es", "form-submission"]));
    }
  } catch (ex) {}
  throw new Error(`Unknown entity type "${type}".`);
};
exports.getElasticsearchEntity = getElasticsearchEntity;
const listElasticsearchEntities = params => {
  const {
    context
  } = params;
  return context.db.registry.getItems(item => {
    return item.tags.includes("es");
  });
};
exports.listElasticsearchEntities = listElasticsearchEntities;

//# sourceMappingURL=getElasticsearchEntity.js.map